package com.flossom.system.service;

import com.flossom.common.core.domain.entity.WxUserScriptLog;
import com.flossom.common.core.domain.req.WxUserScriptReq;

import java.util.List;

/**
 * 发送话术记录Service接口
 *
 * @author flossom
 * @date 2023-12-20
 */
public interface IWxUserScriptLogService {
    /**
     * 查询发送话术记录
     *
     * @param id 发送话术记录主键
     * @return 发送话术记录
     */
    public WxUserScriptLog selectWxUserScriptLogById(Long id);

    /**
     * 查询发送话术记录列表
     *
     * @param wxUserScriptLog 发送话术记录
     * @return 发送话术记录集合
     */
    public List<WxUserScriptLog> selectWxUserScriptLogList(WxUserScriptLog wxUserScriptLog);

    /**
     * 新增发送话术记录
     *
     * @param wxUserScriptLog 发送话术记录
     * @return 结果
     */
    public int insertWxUserScriptLog(WxUserScriptLog wxUserScriptLog);

    /**
     * 修改发送话术记录
     *
     * @param wxUserScriptLog 发送话术记录
     * @return 结果
     */
    public int updateWxUserScriptLog(WxUserScriptLog wxUserScriptLog);

    /**
     * 批量删除发送话术记录
     *
     * @param ids 需要删除的发送话术记录主键集合
     * @return 结果
     */
    public int deleteWxUserScriptLogByIds(Long[] ids);

    /**
     * 删除发送话术记录信息
     *
     * @param id 发送话术记录主键
     * @return 结果
     */
    public int deleteWxUserScriptLogById(Long id);

    void sendScript(WxUserScriptReq wxUserScriptReq);
}
